@@ -18,7 +18,7 @@ from .utils import (
 )
 
 
-__version__ = '1.1.5'
+__version__ = '1.3.5'
 
 
 versioning_manager = VersioningManager()
@@ -70,6 +70,12 @@ def make_versioned(
         manager.track_association_operations
     )
 
+    sa.event.listen(
+        sa.engine.Engine,
+        'set_connection_execution_options',
+        manager.track_cloned_connections
+    )
+
 
 def remove_versioning(
     mapper=sa.orm.mapper,
@@ -96,3 +102,9 @@ def remove_versioning(
         'before_cursor_execute',
         manager.track_association_operations
     )
+
+    sa.event.remove(
+        sa.engine.Engine,
+        'set_connection_execution_options',
+        manager.track_cloned_connections
+    )
